util

package
v0.0.0-...-e094cd6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 15, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConsistentFilepath

func ConsistentFilepath(parts ...string) string

ConsistentFilepath returns a filepath that always uses forward slashes ('/') rather than platform-dependent file path separators.

func ConvertWriter

func ConvertWriter(w io.Writer, err error) send.Sender

ConvertWriter wraps the given written in a send.WriterSender for compatibility with Grip.

Types

type CloseFunc

type CloseFunc func() error

CloseFunc is a function used to close a service or close the client connection to a service.

Jump to