package
Version:
v0.0.0-...-e094cd6
Opens a new window with list of versions in this module.
Published: Jan 15, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
ConsistentFilepath returns a filepath that always uses forward slashes ('/')
rather than platform-dependent file path separators.
ConvertWriter wraps the given written in a send.WriterSender for
compatibility with Grip.
type CloseFunc func() error
CloseFunc is a function used to close a service or close the client
connection to a service.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.